==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AUnknownJimpleType.h <==
// public final class soot.jimple.parser.node.AUnknownJimpleType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b59a0072250dcde4 soot_jimple_parser_node_AUnknownJimpleType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 745dd53d0856ed0 soot_jimple_parser_node_PJimpleType

// header file dependencies
// @dep_header soot_jimple_parser_node_PJimpleType

#include "soot/jimple/parser/node/PJimpleType.h"

#ifndef _JC_soot_jimple_parser_node_AUnknownJimpleType_H_
#define _JC_soot_jimple_parser_node_AUnknownJimpleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TUnknown$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs	_jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs	_jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$refs	_jc_soot_jimple_parser_node_AUnknownJimpleType$refs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs	_jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object	_jc_soot_jimple_parser_node_AUnknownJimpleType$object;

typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods	_jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtable	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$_init$7fe56a92199ed41c(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
extern struct _jc_soot_jimple_parser_node_TUnknown$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$getUnknown$d94c640c7d944cd1(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$setUnknown$f2985d9c921cd6f0(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$getUnknown$d94c640c7d944cd1;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$setUnknown$f2985d9c921cd6f0;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
	struct _jc_soot_jimple_parser_node_TUnknown$object	*(*getUnknown$d94c640c7d944cd1)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setUnknown$f2985d9c921cd6f0)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PJimpleType$vmethods	soot_jimple_parser_node_PJimpleType;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods	soot_jimple_parser_node_AUnknownJimpleType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs {
	struct _jc_soot_jimple_parser_node_TUnknown$object	*__5funknown__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$refs {
    _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs	soot_jimple_parser_node_AUnknownJimpleType;
    _jc_soot_jimple_parser_node_PJimpleType$sub_refs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PJimpleType$sub_nonrefs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs	soot_jimple_parser_node_AUnknownJimpleType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object {
	_jc_soot_jimple_parser_node_AUnknownJimpleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype _jc_soot_jimple_parser_node_AUnknownJimpleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUnknownJimpleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUnknownJimpleType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUnknownJimpleType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AUnknownJimpleType.h <==
// public final class soot.jimple.parser.node.AUnknownJimpleType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b59a0072250dcde4 soot_jimple_parser_node_AUnknownJimpleType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 745dd53d0856ed0 soot_jimple_parser_node_PJimpleType

// header file dependencies
// @dep_header soot_jimple_parser_node_PJimpleType

#include "soot/jimple/parser/node/PJimpleType.h"

#ifndef _JC_soot_jimple_parser_node_AUnknownJimpleType_H_
#define _JC_soot_jimple_parser_node_AUnknownJimpleType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TUnknown$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs	_jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs	_jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$refs	_jc_soot_jimple_parser_node_AUnknownJimpleType$refs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs	_jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object	_jc_soot_jimple_parser_node_AUnknownJimpleType$object;

typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods	_jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtable	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$_init$7fe56a92199ed41c(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TUnknown$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$getUnknown$d94c640c7d944cd1(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnknownJimpleType$method$setUnknown$f2985d9c921cd6f0(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUnknownJimpleType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$getUnknown$d94c640c7d944cd1;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$setUnknown$f2985d9c921cd6f0;
extern _jc_method _jc_soot_jimple_parser_node_AUnknownJimpleType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TUnknown$object	*(*getUnknown$d94c640c7d944cd1)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setUnknown$f2985d9c921cd6f0)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *, struct _jc_soot_jimple_parser_node_TUnknown$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PJimpleType$vmethods	soot_jimple_parser_node_PJimpleType;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vmethods	soot_jimple_parser_node_AUnknownJimpleType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs {
	struct _jc_soot_jimple_parser_node_TUnknown$object	*__5funknown__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$refs {
    _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_refs	soot_jimple_parser_node_AUnknownJimpleType;
    _jc_soot_jimple_parser_node_PJimpleType$sub_refs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PJimpleType$sub_nonrefs	soot_jimple_parser_node_PJimpleType;
    _jc_soot_jimple_parser_node_AUnknownJimpleType$sub_nonrefs	soot_jimple_parser_node_AUnknownJimpleType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUnknownJimpleType$object {
	_jc_soot_jimple_parser_node_AUnknownJimpleType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUnknownJimpleType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUnknownJimpleType$vtype _jc_soot_jimple_parser_node_AUnknownJimpleType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUnknownJimpleType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUnknownJimpleType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUnknownJimpleType_H_ */
